@@ -203,7 +203,7 @@
 #
 class OptionParser
   # :stopdoc:
-  RCSID = %w$Id: optparse.rb 11708 2007-02-12 23:01:19Z shyouhei $[1..-1].each {|s| s.freeze}.freeze
+  RCSID = %w$Id: optparse.rb 13823 2007-11-04 20:17:06Z nobu $[1..-1].each {|s| s.freeze}.freeze
   Version = (RCSID[1].split('.').collect {|s| s.to_i}.extend(Comparable).freeze if RCSID[1])
   LastModified = (Time.gm(*RCSID[2, 2].join('-').scan(/\d+/).collect {|s| s.to_i}) if RCSID[2])
   Release = RCSID[2]
@@ -379,7 +379,7 @@ class OptionParser
       while s = lopts.shift
         l = left[-1].length + s.length
         l += arg.length if left.size == 1 && arg
-        l < max or left << ''
+        l < max or sopts.empty? or left << ''
         left[-1] << if left[-1].empty? then ' ' * 4 else ', ' end << s
       end
 
@@ -398,8 +398,7 @@ class OptionParser
       self
     end
 
-    # :nodoc:
-    def add_banner(to)
+    def add_banner(to)  # :nodoc:
       unless @short or @long
         s = desc.join
         to << " [" + s + "]..." unless s.empty?
@@ -407,8 +406,7 @@ class OptionParser
       to
     end
 
-    # :nodoc:
-    def match_nonswitch?(str)
+    def match_nonswitch?(str) # :nodoc:
       @pattern =~ str unless @short or @long
     end
 
@@ -635,16 +633,17 @@ class OptionParser
       list.each do |opt|
         if opt.respond_to?(:summarize) # perhaps OptionParser::Switch
           opt.summarize(*args, &block)
-        elsif !opt or opt.empty?
+        elsif !opt
           yield("")
+        elsif opt.respond_to?(:each_line)
+          opt.each_line(&block)
         else
           opt.each(&block)
         end
       end
     end
 
-    # :nodoc:
-    def add_banner(to)
+    def add_banner(to)  # :nodoc:
       list.each do |opt|
         if opt.respond_to?(:add_banner)
           opt.add_banner(to)
@@ -1080,7 +1079,7 @@ class OptionParser
       # directly specified pattern(any object possible to match)
       if !(String === o) and o.respond_to?(:match)
         pattern = notwice(o, pattern, 'pattern')
-        conv = (pattern.method(:convert).to_proc if pattern.respond_to?(:convert))
+        conv = pattern.method(:convert).to_proc if pattern.respond_to?(:convert)
         next
       end
 
@@ -1093,7 +1092,7 @@ class OptionParser
         when CompletingHash
         when nil
           pattern = CompletingHash.new
-          conv = (pattern.method(:convert).to_proc if pattern.respond_to?(:convert))
+          conv = pattern.method(:convert).to_proc if pattern.respond_to?(:convert)
         else
           raise ArgumentError, "argument pattern given twice"
         end
@@ -1244,8 +1243,7 @@ class OptionParser
     parse_in_order(argv, &nonopt)
   end
 
-  # :nodoc:
-  def parse_in_order(argv = default_argv, setter = nil, &nonopt)
+  def parse_in_order(argv = default_argv, setter = nil, &nonopt)  # :nodoc:
     opt, arg, sw, val, rest = nil
     nonopt ||= proc {|arg| throw :terminate, arg}
     argv.unshift(arg) if arg = catch(:terminate) {
